Crate ocm_types

Crate ocm_types 

OpenCloudMesh Types

This crate provides the types necessary to implement the OpenCloudMesh 1.3.0.

See opencloudmesh and ocm-server-axum for crates implementing the OpenCloudMesh protocol and the OpenCloudMesh API.

Status

All types of the OpenCloudMesh 1.3.0 are covered.

This crate and depending implementations of the protocol and the API are still in development. Expect breaking changes.

Modules

common
Contains types re-used in different parts of the protocol types.
discovery
This module contains types for the resources provided via the discovery endpoint.
error
invite
Accept an out-of-band invite to establish trust between instances.
notification
Notifications to inform on changes to sent or received share.
share
This module contains types to create a new share.
token