pub enum Capability {
EnforceMfa,
ExchangeToken,
HttpSig,
Invites,
InviteWayf,
Notifications,
ProtocolObject,
WebdavUri,
}Variants
EnforceMfa
to indicate that this OCM Server can apply a Sending Server’s MFA requirements for a Share on their behalf.
ExchangeToken
to indicate that this OCM Server exposes a RFC6749-compliant endpoint, which allows to exchange a secret received in the crate::share::WebDavProperties of a crate::share::NewShare for a short-lived bearer token.
HttpSig
to indicate that this OCM Server supports
[RFC9421] HTTP Message Signatures and advertises public keys in the
format specified by [RFC7517] at the /.well-known/jwks.json
endpoint for signature verification.
Invites
to indicate the server would support acting as an Invite Sender or Invite Receiver OCM Server. This might be useful for suggesting to a user that existing contacts might be upgraded to the more secure (and possibly required) invite flow.
InviteWayf
to indicate that this OCM Server exposes a WAYF Page to facilitate the Invite flow.
Notifications
to indicate that this OCM Server handles notifications to exchange updates on shares and invites.
ProtocolObject
to indicate that this OCM Server can receive a Share Creation Notification whose protocol object contains one property per supported protocol instead of containing the standard name and options properties.
WebdavUri
to indicate that this OCM Server can append a relative URI to the path listed for WebDAV in the appropriate resourceTypes entry