pub struct SshProperties {
pub access_types: Vec<AccessType>,
pub uri: String,
}Fields
access_types: Vec<AccessType>The type of access being granted to the remote resource.
If omitted, it defaults to ['remote'].
uri: StringThe full address to be used for ssh or scp access, in the
username@host.fqdn:port/resource/path, where authentication
expected to take place via public/private key.