pub struct WebAppProperties {
pub uri: String,
pub view_mode: WebAppViewMode,
pub shared_secret: Option<String>,
}Fields
uri: StringAn URI to a client-browsable view of the remote resource,
such that
users may use a web application available at the sender site.
The URI SHOULD be relative, such as a key or a UUID, in which case
the prefix exposed by the /.well-known/ocm endpoint MUST be used
to access the resource, or it MAY be absolute, including a hostname.
The latter is NOT recommended because of security concerns.
In all cases, for a folder resource, the composed URI acts
as the root path, such that other files located within SHOULD
be accessible by appending their relative path to that URI.
view_mode: WebAppViewModeThe permissions granted to the sharee.
An optional secret to be used to access the remote web
app, such as
a bearer token. To prevent leaking it in logs it MUST NOT appear
in any URI. If a code is provided, then the sending host MUST
accept the short-lived bearer token when serving the web app,
which can be exchanged in the code flow interaction. The exchange
MAY already have happened if the recipient accessed the underlying
resource via WebDAV, in a multi-protocol scenario. In this case,
the sharedSecret SHOULD be omitted.