WebDavProperties

Struct WebDavProperties 

pub struct WebDavProperties {
    pub access_types: Vec<AccessType>,
    pub uri: String,
    pub shared_secret: Option<String>,
    pub refresh_token: Option<String>,
    pub permissions: Vec<WebDavPermissions>,
    pub requirements: Vec<WebDavRequirements>,
}

Fields

access_types: Vec<AccessType>

The type of access being granted to the remote resource. If omitted, it defaults to ['remote'].

  • remote signals the recipient that the resource is available for remote access and interactive browsing.
  • datatx signals the recipient to transfer the resource from the given URI. The recipient MAY delegate a third-party service to execute the data transfer on their behalf.
uri: String

An URI to access the remote resource. The URI SHOULD be relative, such as a key or a UUID, in which case the prefix exposed by the /.well-known/ocm endpoint MUST be used to access the resource, or it MAY be absolute, including a hostname. The latter is NOT recommended because of security concerns. In all cases, for a folder resource, the composed URI acts as the root path, such that other files located within SHOULD be accessible by appending their relative path to that URI.

shared_secret: Option<String>

An optional secret to be used to access the resource, such as a bearer token. If a refreshToken is provided, it SHOULD be used instead via the code flow interaction, and the sharedSecret SHOULD be omitted. To prevent leaking it in logs it MUST NOT appear in any URI.

refresh_token: Option<String>

A Token to be exchanged for a short-lived bearer token at the tokenEndPoint of the Sending Server for access to the shared resource.

permissions: Vec<WebDavPermissions>

The permissions granted to the sharee.

requirements: Vec<WebDavRequirements>

A list of requirements that the recipient provider MUST fulfill to access the resource. Requirements are optional, but if it is present it MUST NOT be empty. A recipient provider MUST reject a share whose requirements it does not understand.